@@ -149,14 +149,14 @@ class VideoLog(object):
                 filename = obj_id + '.jpg'
                 file_thumb = filename[:-4] + "_thumb.jpg"
                 if isinstance(image, dict):
-                    cv2.imwrite(os.path.join(self._dest_path, filename), image["input_image"])
+                    cv2.imwrite(os.path.join(self._dest_path, filename), cv2.cvtColor(image["input_image"], cv2.COLOR_BGR2RGB))
                     file_stat_img = os.stat(os.path.join(self._dest_path, filename))
 
                     if max(image["input_image"].shape) > THUMB_SIZE:
                         img, _ = resize_image_scale(image["input_image"], THUMB_SIZE)
-                        cv2.imwrite(os.path.join(self._dest_path, file_thumb), img)
+                        cv2.imwrite(os.path.join(self._dest_path, file_thumb), cv2.cvtColor(img, cv2.COLOR_BGR2RGB))
                     else:
-                        cv2.imwrite(os.path.join(self._dest_path, file_thumb), image["input_image"])
+                        cv2.imwrite(os.path.join(self._dest_path, file_thumb), cv2.cvtColor(image["input_image"], cv2.COLOR_BGR2RGB))
                     file_stat_thumb = os.stat(os.path.join(self._dest_path, file_thumb))
 
                     img_data = {
@@ -175,14 +175,14 @@ class VideoLog(object):
                     if 'video_data' in image["frame_data"]:
                         img_data['video_data'] = image["frame_data"]['video_data']
                 else:
-                    cv2.imwrite(os.path.join(self._dest_path, filename), image[0])
+                    cv2.imwrite(os.path.join(self._dest_path, filename), cv2.cvtColor(image[0], cv2.COLOR_BGR2RGB))
                     file_stat_img = os.stat(os.path.join(self._dest_path, filename))
 
                     if max(image[0].shape) > THUMB_SIZE:
                         img, _ = resize_image_scale(image[0], THUMB_SIZE)
-                        cv2.imwrite(os.path.join(self._dest_path, file_thumb), img)
+                        cv2.imwrite(os.path.join(self._dest_path, file_thumb), cv2.cvtColor(img, cv2.COLOR_BGR2RGB))
                     else:
-                        cv2.imwrite(os.path.join(self._dest_path, file_thumb), image[0])
+                        cv2.imwrite(os.path.join(self._dest_path, file_thumb), cv2.cvtColor(image[0], cv2.COLOR_BGR2RGB))
                     file_stat_thumb = os.stat(os.path.join(self._dest_path, file_thumb))
 
                     img_data = {
